Learn R Programming

AquaAnalytix (version 0.1.0)

Salinity: Salinity in Water using Mohr-Knudsen Method

Description

Salinity refers to the concentration of dissolved salts in water, typically measured in parts per thousand (ppt). APHA(2017,ISBN:9780875532875).

Usage

Salinity (chl_std_seawater, T1, T2)

Value

Salinity in Water(gm/L)

Arguments

chl_std_seawater

Chlorinity of standard seawater

T1

Volume of silver nitrate required to titrate a sample

T2

Volume of silver nitrate required to titrate standard seawater

References

APHA, 2017. Standard methods for examination of water and wastewater, 23rd edn. APHA, AWWA, WPCF, Washington

Examples

Run this code
Salinity (19, 25, 30)

Run the code above in your browser using DataLab