Learn R Programming

AquaAnalytix (version 0.1.0)

TA: Total Alkalinity using Double Indicator Titration Method

Description

Total alkalinity measures the water's capacity to neutralize acids, reflecting the presence of bicarbonates, carbonates, and hydroxides.APHA(2017,ISBN:9780875532875).

Usage

TA (P, M, N, Vol)

Value

Total alkalinity (in mg/L)

Arguments

P

Volume of sulp. acid used for phenolphthalein end point

M

Volume of sulp. acid used for methyl orange end point

N

Normality of sulp. acid

Vol

Volume of sample (mL)

References

APHA, 2017. Standard methods for examination of water and wastewater, 23rd edn. APHA, AWWA, WPCF, Washington

Examples

Run this code
TA (5, 10, 0.02, 100)

Run the code above in your browser using DataLab